<?php
/**
 *----------------- include ------------------------------------------
 */
include_once(get_template_directory() . '/inc/tools.php');
include_once(get_template_directory() . '/inc/plugins/plugins.php');
include_once(get_template_directory() . '/inc/import/import.php');

include_once(get_template_directory() . '/inc/meta-box.php');
include_once(get_template_directory() . '/inc/templates.php');
require_once('inc/classes/wdevia_base_class.php');
require_once('inc/fonts.php');

function comdigex_init()
{
    return comdigex_base_class::instance();
}

comdigex_init();

require_once('inc/base-functions.php');

include_once(get_template_directory() . '/inc/panel/PanelClass.php');
include_once(get_template_directory() . '/inc/panel/shortcode_settings.php');

/** Register all navigation menus */
require_once('inc/navigation.php');

/** Add menu walkers for top-bar and off-canvas */
require_once('inc/class-top-bar-walker.php');
require_once('inc/class-mobile-walker.php');

require_once('inc/widget-areas.php');
require_once('inc/woocommerce.php');
require_once('inc/theme-support.php');

include_once(get_template_directory() . '/inc/mega-menu.php');
require_once(get_template_directory() . '/inc/aq_resizer.php');

require_once('inc/enqueue-scripts.php');
require_once('inc/image-presets.php');



/* Add post formats */

if (function_exists('add_theme_support')) {
  add_theme_support('post-thumbnails');
  add_theme_support('post-formats', array('gallery', 'video', 'audio'));
  add_theme_support('automatic-feed-links');
  add_theme_support('custom-background');
  add_theme_support('title-tag');
  add_theme_support('woocommerce');
  add_theme_support('html5', array('search-form'));
  add_theme_support('editor-styles');
  add_editor_style('editor.css');
  add_theme_support('align-wide');
  // -- Disable custom font sizes
  add_theme_support('disable-custom-font-sizes');

// -- Editor Font Sizes
  add_theme_support('editor-font-sizes', array(
    array(
      'name' => __('small', 'comdigex'),
      'shortName' => __('S', 'comdigex'),
      'size' => 14,
      'slug' => 'small'
    ),
    array(
      'name' => __('regular', 'comdigex'),
      'shortName' => __('M', 'comdigex'),
      'size' => 16,
      'slug' => 'regular'
    ),
    array(
      'name' => __('large', 'comdigex'),
      'shortName' => __('L', 'comdigex'),
      'size' => 28,
      'slug' => 'large'
    ),
  ));
  // -- Editor Color Palette
  add_theme_support('editor-color-palette', array(
    array(
      'name' => __('Primary Color:', 'comdigex'),
      'slug' => 'primary',
      'color' => '#B15BCD',
    ),
    array(
      'name' => __('Secondary Color:', 'comdigex'),
      'slug' => 'secondary',
      'color' => '#412AAB',
    ),
  ));
}

/**
 * ---------------menu--------------------------------
 */
$comdigex_counter = 1;

class comdigex_top_bar_walker extends Walker_Nav_Menu
{

    static protected $menu_bg_test;
    public $comdigex_megamenu;
    public $comdigex_count;

    public function __construct()
    {
        $this->comdigex_megamenu = 0;
        $this->comdigex_count = 0;
    }

    function start_el(&$output, $item, $depth = 0, $args = Array(), $id = 0)
    {

        $comdigex_class = "";
        if (is_object($args)) {
            global $comdigex_counter;
            if ($item->mega_menu == 1) {
                $comdigex_class = 'mega-menu';
                $this->comdigex_megamenu = $item->ID;
            }
            self::$menu_bg_test = $item->mega_menu_bg_image;
            $indent = ($depth) ? str_repeat("\t", $depth) : '';
            $class_names = $value = '';

            $classes = empty($item->classes) ? array() : (array)$item->classes;
            $classes[] = ($item->current) ? 'active' : '';
            $classes[] = ($args->has_children) ? ' is-dropdown-submenu-parent opens-right not-click' : '';
            $args->link_before = (in_array('section', $classes)) ? '<label>' : '';
            $args->link_after = (in_array('section', $classes)) ? '</label>' : '';
            $output .= (in_array('section', $classes));
            $class_names = !empty($classes) ? implode(' ', $classes) . ' ' : '';
            $class_names .= ($args->has_children) ? 'has-dropdown not-click ' . $comdigex_class : '';
            $parent = $item->menu_item_parent;
            if ($parent == 0) {
                $comdigex_counter++;

            }

            $current_page = empty($item->classes[4]) ? '' : $item->classes[4];
            $class_names .= ' color-' . $comdigex_counter . ' ' . $current_page;
            $class_names = strlen(trim($class_names)) > 0 ? ' class="' . esc_attr($class_names) . '"' : '';

            $output .= $indent . '<li' . $value . $class_names . '>';


            $attributes = !empty($item->attr_title) ? ' title="' . esc_attr($item->attr_title) . '"' : '';
            $attributes .= !empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
            $attributes .= !empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
            $attributes .= !empty($item->url) ? ' href="' . esc_url($item->url) . '"' : '';


            $item_output = $args->before;

            $item_output .= (!in_array('section', $classes)) ? '<a' . $attributes . '>' : '';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID);
            $item_output .= $args->link_after;

            //post image
            $has_featured_image = array_search('menu-item-object-post', $classes);
            if ($has_featured_image !== false && $this->comdigex_megamenu != 0) {
                $postID = url_to_postid($item->url);
                $image_src = get_the_post_thumbnail_url($postID);
                $item_output .= "<img src='" . $image_src . "'/>";
            }


            $item_output .= (!in_array('section', $classes)) ? '</a>' : '';
            $item_output .= $args->after;

            if ($this->comdigex_megamenu === intval($item->menu_item_parent) && $this->comdigex_megamenu != 0) {
                $this->comdigex_count++;
                if ($this->comdigex_count > 4) {

                    $output .= "</ul></li><li class=\" mega-menu-column\"><ul><li>";
                    $this->comdigex_count = 1;
                }

            }

            $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
        }


    }

    function end_el(&$output, $item, $depth = 0, $args = Array())
    {
        if ($this->comdigex_megamenu == 0) {
            $output .= '</li>' . "\n";
        }
    }

    function start_lvl(&$output, $depth = 0, $args = Array())
    {
        $indent = str_repeat("\t", $depth);
        if (isset($menu_bg_test) && $menu_bg_test != "") {
            $output .= "\n" . $indent . '
<ul class="sub-menu dropdown " style = "background-image : url(' . self::$menu_bg_test . ')">
	' . "\n";
        } else {

            $output .= "\n" . $indent . '<ul class="submenu is-dropdown-submenu ">' . "\n";
            if ($this->comdigex_megamenu != 0) {
                $output .= "<li class=\" mega-menu-column\"><ul> ";
            }
        }

    }

    function end_lvl(&$output, $depth = 0, $args = Array())
    {
        $indent = str_repeat("\t", $depth);
        if ($this->comdigex_megamenu != 0) {
            $output .= "</ul></li> ";
        }
        $output .= $indent . ' </ul>' . "\n";
    }

    function display_element($element, &$children_elements, $max_depth, $depth = 0, $args, &$output)
    {
        $id_field = $this->db_fields['id'];
        if (is_object($args[0])) {
            $args[0]->has_children = !empty($children_elements[$element->$id_field]);
        }
        return parent::display_element($element, $children_elements, $max_depth, $depth, $args, $output);
    }

}

//------------ Tags size ---------------
function comdigex_tag_cloud_widget($args)
{
    $args['largest'] = 15; //largest tag
    $args['smallest'] = 15; //smallest tag
    $args['unit'] = 'px'; //tag font unit
    return $args;
}

add_filter('widget_tag_cloud_args', 'comdigex_tag_cloud_widget');


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327636&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        