<?php


class comdigex_base_class
{

    private static $instance;
    public $helpers;
    public $customizer;
    public $activation;
    public $integrations;
    public $widgets;
    public $template;
    public $page_settings;
    public $widgetized_pages;

    public static function instance()
    {
        if (!isset(self::$instance) && !(self::$instance instanceof comdigex_base_class)) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    public function __construct()
    {
        $this->default_parameters();
        $this->setup();
    }

    // Integration getter helper
    public function get($integration)
    {
        return $this->integrations->get($integration);
    }


    private function setup()
    {
        add_action('after_setup_theme', array($this, 'setup_theme'));
    }

    public function setup_theme()
    {
        load_theme_textdomain('comdigex', get_template_directory() . '/languages');
        add_editor_style('css/editor-style.css');

        add_theme_support('custom-background', apply_filters('comdigex_custom_background_args', array('default-color' => 'ffffff',
            'default-image' => '',)));

    }

    public function default_parameters()
    {

        define("THEME_NAME", "Comdigex");
        // Colors
        define('WD_PRIMARY_COLOR', '#B15BCD');
        define('WD_SECONDARY_COLOR', '#412AAB');
        define('WD_ACCENT_COLOR', '#FA4C9A');
        define('WD_TEXT_COLOR', '#718494');
        define('WD_SECONDARY_TEXT_COLOR', '#A6AAB7');
        define('WD_HEADER_COLOR', '#2E325B');
        define('WD_BODY_BG_COLOR', '#fff');

        // Layout
        define('WD_BOXED_LAYOUT', "off");
        define('WD_MENU_MOBILE_LAYOUT', "on");
        define('WD_HEADER_CONTAIN_TO_GRID', "on");
        define('WD_STICK_MENU_TO_TOP', "off");
        define('WD_PAGE_LOADING_ANIMATION', "off");
        define('WD_SHOW_THE_LOGO', "off");
        define('WD_SHOW_WEBSITE_TITLE', "on");


        // Topbar Colors
        define('WD_HEADER_BG_COLOR', '#452BA0');
        define('WD_NAV_TEXT_COLOR', '#fff');
        define('WD_STICKY_NAV_BG_COLOR', '#162466');
        define('WD_STICKY_NAV_TEXT_COLOR', '#ffffff');
        define('WD_HOVER_STICKY_NAV_TEXT_COLOR', '#ffffff');
        define('WD_HOVER_NAV_TEXT_COLOR', '#162466');


        // Footer Colors
        define('WD_FOOTER_BG_COLOR', '#fff0');
        define('WD_FOOTER_TEXT_COLOR', '#162466');
        define('WD_COPYRIGHT_BG', '#F0F4FB');
        define('WD_COPYRIGHT_TEXT_COLOR', '#162466');


        define('WD_LOGO_HEIGHT', '40');

        define('WD_BODY_FONT_FAMILY', "Poppins");
        define('WD_BODY_FONT_FAMILY_FALLBACK', "'Open Sans', sans-serif");

        define('WD_HEAD_FONT_FAMILY', "Poppins");
        define('WD_HEAD_FONT_FAMILY_FALLBACK', "'Open Sans', sans-serif");

        define('WD_NAV_FONT_FAMILY', "Poppins");
        define('WD_NAV_FONT_FAMILY_FALLBACK', "'Open Sans', sans-serif");


        define('WD_BODY_BACKGROUND_IMAGE', "#fff");


    }

    /**
     *
     * // initialize options
     */

    public static function initialize_options()
    {

        if (!get_option("wd_options_array")) {
            $options_array = get_option("wd_options_array");

            $options_array = array(
                "primary_color" => WD_PRIMARY_COLOR,
                "secondary_color" => WD_SECONDARY_COLOR,
                "accent_color" => WD_ACCENT_COLOR,
                "text_color" => WD_TEXT_COLOR,
                "secondary_text_color" => WD_SECONDARY_TEXT_COLOR,
                "header_text_color" => WD_HEADER_COLOR,
                "body_bg_color" => WD_BODY_BG_COLOR,
                "header_bg_color" => WD_HEADER_BG_COLOR,
                "nav_text_color" => WD_NAV_TEXT_COLOR,
                "sticky_nav_bg_color" => WD_STICKY_NAV_BG_COLOR,
                "sticky_nav_text_color" => WD_STICKY_NAV_TEXT_COLOR,
                "hover_sticky_nav_text_color" => WD_HOVER_STICKY_NAV_TEXT_COLOR,
                "hover_nav_text_color" => WD_HOVER_NAV_TEXT_COLOR,
                "footer_bg_color" => WD_FOOTER_BG_COLOR,
                "footer_text_color" => WD_FOOTER_TEXT_COLOR,
                "copyright_bg_color" => WD_COPYRIGHT_BG,
                "copyright_text_color" => WD_COPYRIGHT_TEXT_COLOR,
                "404_background_image" => "",
                "products_per_page" => "9",
                "product_column" => "4",
                "footer_bg" => "",
                "copyright_text" => "",
                "powered_text" => "",
                "footer_column" => "four_columns",
                "menu_style" => "creative",
                "wd_height_logo" => WD_LOGO_HEIGHT,

                "body_font_family" => WD_BODY_FONT_FAMILY,
                "body_font_style" => "normal",
                "body_font_weight" => "400",
                "body_font_to_load" => "300 400 500 600 700",
                "body_font_size" => "",
                "body_letter_spacing" => "",
                "body_font_subsets" => "",
                "head_font_family" => WD_HEAD_FONT_FAMILY,
                "head_font_style" => "normal",
                "head_font_size" => "",
                "head_font_weight" => "600",
                "head_font_subsets" => "latin",
                "head_letter_spacing" => "",
                "nav_font_family" => WD_NAV_FONT_FAMILY,
                "nav_font_style" => "normal",
                "nav_font_weight" => "500",
                "nav_font_size" => "",
                "nav_font_subsets" => "latin",
                "nav_letter_spacing" => "",
                "wd_theme_custom_js" => "",

                "boxed_layout" => WD_BOXED_LAYOUT,
                "menu_mobile_layout" => WD_MENU_MOBILE_LAYOUT,
                "header_contain_to_grid" => WD_HEADER_CONTAIN_TO_GRID,
                "stick_menu_to_top" => WD_STICK_MENU_TO_TOP,
                "page_loading_animation" => WD_PAGE_LOADING_ANIMATION,
                "show_the_logo" => WD_SHOW_THE_LOGO,
                "show_website_title" => WD_SHOW_WEBSITE_TITLE,

                "action_button" => "",
                "body_background_image" => "",
                "bg_home_page" => "",
                "Logo_link" => "#Logo",
                "logo_height" => WD_LOGO_HEIGHT,
                "logo_padding" => "0",
                "google_key_map" => "",
                "title_page_bg" => "",
            );
            update_option("wd_options_array", $options_array);
        }
    }

}