<?php
if ( ! function_exists( 'add_action' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Register styles and scripts
 */

function comdigex_admin_scripts_init() {

	wp_register_script( 'bootstrap.min', get_template_directory_uri() . '/js/bootstrap.min.js', array(
		'jquery',
		'jquery-ui-core',
		'jquery-ui-widget',
		'jquery-ui-mouse',
		'jquery-ui-tabs',
		'jquery-ui-droppable',
		'jquery-ui-sortable'
	), false, false );

}

add_action( 'admin_init', 'comdigex_admin_scripts_init' );


class comdigex_Import {

	public $message = "";
	public $attachments = false;


	function init_comdigex_import() {
		if ( isset( $_REQUEST['import_option'] ) ) {
			$import_option = $_REQUEST['import_option'];
			if ( $import_option == 'content' ) {
			} elseif ( $import_option == 'custom_sidebars' ) {
				$this->import_custom_sidebars( 'custom_sidebars.txt' );
			} elseif ( $import_option == 'widgets' ) {
				$this->import_widgets( 'widgets.txt' );
			} elseif ( $import_option == 'options' ) {
				$this->import_options( 'options.txt' );
			} elseif ( $import_option == 'menus' ) {
				$this->import_menus( 'menus.txt' );
			} elseif ( $import_option == 'settingpages' ) {
				$this->import_settings_pages( 'settingpages.txt' );
			} elseif ( $import_option == 'complete_content' ) {
				$this->import_options( 'options.txt' );
				$this->import_widgets( 'widgets.txt' );
				$this->import_menus( 'menus.txt' );
				$this->import_settings_pages( 'settingpages.txt' );
				$this->message = esc_html__( "Content imported successfully", "webdevia" );
			}
		}
	}

	public function comdigex_import_content( $file ) {
		ob_start();
		if ( ! class_exists( 'WP_Importer' ) ) {
			$class_wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';
			require_once( $class_wp_importer );
		}
		if ( ! class_exists( 'WP_Import' ) ) {
			require_once( plugin_dir_path( __FILE__ ) . '/class.wordpress-importer.php' );
		}
		$comdigex_import = new WP_Import();
		set_time_limit( 0 );
		$path = plugin_dir_path( __FILE__ ) . '/files/' . $file;
		if ( ! file_exists( $path ) ) {
			echo 'error';
			wp_send_json_error( esc_html__( "Content file not found", "webdevia" ) );
		}

		print $path;
		$comdigex_import->fetch_attachments = $this->attachments;
		$returned_value                     = $comdigex_import->import( $path );
		if ( is_wp_error( $returned_value ) ) {
			$this->message = esc_html__( "An Error Occurred During Import", "webdevia" );
			echo 'error';
			wp_send_json_error( esc_html__( "An Error Occurred During Content Import", "webdevia" ) );
		} else {
			$this->message = esc_html__( "Content imported successfully", "webdevia" );
		}
		ob_get_clean();
	}

	public function comdigex_available_widgets() {

		global $wp_registered_widget_controls;

		$widget_controls = $wp_registered_widget_controls;

		$available_widgets = array();

		foreach ( $widget_controls as $widget ) {

			if ( ! empty( $widget['id_base'] ) && ! isset( $available_widgets[ $widget['id_base'] ] ) ) { // no dupes

				$available_widgets[ $widget['id_base'] ]['id_base'] = $widget['id_base'];
				$available_widgets[ $widget['id_base'] ]['name']    = $widget['name'];

			}

		}

		return apply_filters( 'wie_available_widgets', $available_widgets );

	}

	public function import_widgets( $file ) {

		if ( ! file_exists( dirname( __FILE__ ) . $file ) ) {
			echo 'error';
			wp_send_json_error( esc_html__( "Widgets file not found", "webdevia" ) );
		} else {
			$myfile = fopen( dirname( __FILE__ ) . $file, "r" ) or die( "Unable to open file!" );
			$data = fread( $myfile, filesize( dirname( __FILE__ ) . $file ) );
			fclose( $myfile );
		}

		/*
		$data = file_get_contents( "./demo-files/widgets.txt", FILE_USE_INCLUDE_PATH );
		$data = json_decode( $data );

		// Delete import file
		unlink( $file );*/

		$data = json_decode( $data );


		global $wp_registered_sidebars;

		// Have valid data?
		// If no data or could not decode
		if ( empty( $data ) || ! is_object( $data ) ) {
			echo 'error';
			wp_send_json_error( esc_html__( "Widgets import data file could not be read or is empty.", 'webdevia' ) );
			wp_die(
				__( 'Import data could not be read. Please try a different file.', 'webdevia' ),
				'',
				array( 'back_link' => true )
			);
		}

		// Hook before import
		do_action( 'wie_before_import' );
		$data = apply_filters( 'import_widgets', $data );

		// Get all available widgets site supports
		$available_widgets = $this->comdigex_available_widgets();

		// Get all existing widget instances
		$widget_instances = array();
		foreach ( $available_widgets as $widget_data ) {
			$widget_instances[ $widget_data['id_base'] ] = get_option( 'widget_' . $widget_data['id_base'] );
		}

		// Begin results
		$results = array();

		// Loop import data's sidebars
		foreach ( $data as $sidebar_id => $widgets ) {

			// Skip inactive widgets
			// (should not be in export file)
			if ( 'wp_inactive_widgets' == $sidebar_id ) {
				continue;
			}

			// Check if sidebar is available on this site
			// Otherwise add widgets to inactive, and say so
			if ( isset( $wp_registered_sidebars[ $sidebar_id ] ) ) {
				$sidebar_available    = true;
				$use_sidebar_id       = $sidebar_id;
				$sidebar_message_type = 'success';
				$sidebar_message      = '';
			} else {
				$sidebar_available    = false;
				$use_sidebar_id       = 'wp_inactive_widgets'; // add to inactive if sidebar does not exist in theme
				$sidebar_message_type = 'error';
				$sidebar_message      = __( 'Sidebar does not exist in theme (using Inactive)', 'widget-importer-exporter' );
			}

			// Result for sidebar
			$results[ $sidebar_id ]['name']         = ! empty( $wp_registered_sidebars[ $sidebar_id ]['name'] ) ? $wp_registered_sidebars[ $sidebar_id ]['name'] : $sidebar_id; // sidebar name if theme supports it; otherwise ID
			$results[ $sidebar_id ]['message_type'] = $sidebar_message_type;
			$results[ $sidebar_id ]['message']      = $sidebar_message;
			$results[ $sidebar_id ]['widgets']      = array();

			// Loop widgets
			foreach ( $widgets as $widget_instance_id => $widget ) {

				echo $sidebar_id . ' - ' . $widget_instance_id;

				$fail = false;

				// Get id_base (remove -# from end) and instance ID number
				$id_base            = preg_replace( '/-[0-9]+$/', '', $widget_instance_id );
				$instance_id_number = str_replace( $id_base . '-', '', $widget_instance_id );

				// Does site support this widget?
				if ( ! $fail && ! isset( $available_widgets[ $id_base ] ) ) {
					$fail                = true;
					$widget_message_type = 'error';
					$widget_message      = __( 'Site does not support widget', 'widget-importer-exporter' ); // explain why widget not imported
				}

				// Filter to modify settings object before conversion to array and import
				// Leave this filter here for backwards compatibility with manipulating objects (before conversion to array below)
				// Ideally the newer wie_widget_settings_array below will be used instead of this
				$widget = apply_filters( 'wie_widget_settings', $widget ); // object

				// Convert multidimensional objects to multidimensional arrays
				// Some plugins like Jetpack Widget Visibility store settings as multidimensional arrays
				// Without this, they are imported as objects and cause fatal error on Widgets page
				// If this creates problems for plugins that do actually intend settings in objects then may need to consider other approach: https://wordpress.org/support/topic/problem-with-array-of-arrays
				// It is probably much more likely that arrays are used than objects, however
				$widget = json_decode( json_encode( $widget ), true );

				// Filter to modify settings array
				// This is preferred over the older wie_widget_settings filter above
				// Do before identical check because changes may make it identical to end result (such as URL replacements)
				$widget = apply_filters( 'wie_widget_settings_array', $widget );

				// Does widget with identical settings already exist in same sidebar?
				if ( ! $fail && isset( $widget_instances[ $id_base ] ) ) {

					// Get existing widgets in this sidebar
					$sidebars_widgets = get_option( 'sidebars_widgets' );
					$sidebar_widgets  = isset( $sidebars_widgets[ $use_sidebar_id ] ) ? $sidebars_widgets[ $use_sidebar_id ] : array(); // check Inactive if that's where will go

					// Loop widgets with ID base
					$single_widget_instances = ! empty( $widget_instances[ $id_base ] ) ? $widget_instances[ $id_base ] : array();
					foreach ( $single_widget_instances as $check_id => $check_widget ) {

						// Is widget in same sidebar and has identical settings?
						if ( in_array( "$id_base-$check_id", $sidebar_widgets ) && (array) $widget == $check_widget ) {

							$fail                = true;
							$widget_message_type = 'warning';
							$widget_message      = __( 'Widget already exists', 'widget-importer-exporter' ); // explain why widget not imported

							break;

						}

					}

				}

				// No failure
				if ( ! $fail ) {

					// Add widget instance
					$single_widget_instances   = get_option( 'widget_' . $id_base ); // all instances for that widget ID base, get fresh every time
					$single_widget_instances   = ! empty( $single_widget_instances ) ? $single_widget_instances : array( '_multiwidget' => 1 ); // start fresh if have to
					$single_widget_instances[] = $widget; // add it

					// Get the key it was given
					end( $single_widget_instances );
					$new_instance_id_number = key( $single_widget_instances );

					// If key is 0, make it 1
					// When 0, an issue can occur where adding a widget causes data from other widget to load, and the widget doesn't stick (reload wipes it)
					if ( '0' === strval( $new_instance_id_number ) ) {
						$new_instance_id_number                             = 1;
						$single_widget_instances[ $new_instance_id_number ] = $single_widget_instances[0];
						unset( $single_widget_instances[0] );
					}

					// Move _multiwidget to end of array for uniformity
					if ( isset( $single_widget_instances['_multiwidget'] ) ) {
						$multiwidget = $single_widget_instances['_multiwidget'];
						unset( $single_widget_instances['_multiwidget'] );
						$single_widget_instances['_multiwidget'] = $multiwidget;
					}

					// Update option with new widget
					update_option( 'widget_' . $id_base, $single_widget_instances );

					// Assign widget instance to sidebar
					$sidebars_widgets                      = get_option( 'sidebars_widgets' ); // which sidebars have which widgets, get fresh every time
					$new_instance_id                       = $id_base . '-' . $new_instance_id_number; // use ID number from new widget instance
					$sidebars_widgets[ $use_sidebar_id ][] = $new_instance_id; // add new instance to sidebar
					update_option( 'sidebars_widgets', $sidebars_widgets ); // save the amended data

					// Success message
					if ( $sidebar_available ) {
						$widget_message_type = 'success';
						$widget_message      = __( 'Imported', 'widget-importer-exporter' );
					} else {
						$widget_message_type = 'warning';
						$widget_message      = __( 'Imported to Inactive', 'widget-importer-exporter' );
					}

				}

				// Result for widget instance
				$results[ $sidebar_id ]['widgets'][ $widget_instance_id ]['name']         = isset( $available_widgets[ $id_base ]['name'] ) ? $available_widgets[ $id_base ]['name'] : $id_base; // widget name or ID if name not available (not supported by site)
				$results[ $sidebar_id ]['widgets'][ $widget_instance_id ]['title']        = ! empty( $widget['title'] ) ? $widget['title'] : __( 'No Title', 'widget-importer-exporter' ); // show "No Title" if widget instance is untitled
				$results[ $sidebar_id ]['widgets'][ $widget_instance_id ]['message_type'] = $widget_message_type;
				$results[ $sidebar_id ]['widgets'][ $widget_instance_id ]['message']      = $widget_message;

			}

		}
	}


	public function import_options( $file ) {
		$options = $this->file_options( $file, 'Options' );
		update_option( 'wd_options_array', $options );
		$this->message = esc_html__( "Options imported successfully", "webdevia" );
	}

	public function import_menus( $file ) {
		global $wpdb;
		$comdigex_terms_table = $wpdb->prefix . "terms";
		$comdigex_terms_table = esc_sql( $comdigex_terms_table );
		$this->menus_data     = $this->file_options( $file, 'Menus' );

		$locations            = get_theme_mod( 'nav_menu_locations' );
		$menuname             = 'primary-menu';
		$menu_exists          = wp_get_nav_menu_object( $menuname );
		$menu_id              = $menu_exists->term_id;
		$locations['primary'] = $menu_id;

		set_theme_mod( 'nav_menu_locations', $locations );


	}

	public function import_settings_pages( $file ) {
		$pages = $this->file_options( $file, 'Settings' );

		foreach ( $pages as $comdigex_page_option => $comdigex_page_id ) {
			update_option( $comdigex_page_option, $comdigex_page_id );
		}

		$demo = 'demo-1';
		if ( ! empty( $_POST['example'] ) ) {
			$demo = $_POST['example'];
		}

		switch ( $demo ) {
			case 'demo-1':
				$page = 'Main Home';
				break;
			case 'demo-2':
				$page = 'Digital Marketing Home';
				break;
			case 'demo-3':
				$page = 'Home – Digital Agency';
				break;
			case 'demo-4':
				$page = 'Home – Minimalist Home';
				break;
			case 'demo-5':
				$page = 'Home -Technology Home';
				break;
			case 'demo-6':
				$page = 'Home consulting';
				break;
			case 'demo-7':
				$page = 'Business home';
				break;
			default :
				$page = 'Main Home';
				break;
		}
		$home_page = get_option( "page_on_front" );
		if ( ! $home_page || ! is_page( $home_page ) ) {
			$home = get_page_by_title( $page, OBJECT, 'page' );
			var_dump( $home );
			update_option( 'page_on_front', $home->ID );
		}
		$blog_page = get_option( "page_for_posts" );
		if ( ! $blog_page || ! is_page( $blog_page ) ) {
			$blog = get_page_by_title( 'Blog' );
			update_option( 'page_for_posts', $blog->ID );
		}
		$home_page   = get_option( 'page_on_front' );
		$value       = get_post_meta( $home_page, '_custom_options', true );
		$value_array = explode( '|', $value );
		if ( ! empty( $value_array ) && count( $value_array ) != 0 ) {
			foreach ( $value_array as $arrayer ) {
				$contenter = explode( '::', $arrayer );
				if ( ! empty( $contenter ) && count( $contenter ) != 0 ) {
					comdigex_save_option( $contenter[0], $contenter[1] );
				}
			}
		}
		delete_post_meta( $home_page, '_custom_options' );
	}

	public function file_options( $file, $text ) {
		$file_content    = "";
		$file_for_import = plugin_dir_path( __FILE__ ) . '/files/' . $file;
		if ( file_exists( $file_for_import ) ) {
			$file_content = $this->comdigex_file_contents( $file_for_import );
		} else {
			$this->message = esc_html__( "File doesn't exist", "webdevia" );
			echo 'error';
			wp_send_json_error( esc_html__( $text . " file doesn't exist", "webdevia" ) );
		}
		if ( $file_content ) {
			$unserialized_content = unserialize( $file_content );
			$json_array           = json_decode( $file_content );
			/*print_r($json_array);*/
			if ( is_array( $unserialized_content ) ) {
				if ( $text == 'Options' ) {
					echo 'error';
					wp_send_json_error( 'Unserialized' );
				}

			}

			// print_r($json_array);
			return $unserialized_content;
		} else {
			echo 'error';
			wp_send_json_error( esc_html__( $text . " import data file could not be read or is empty.", 'webdevia' ) );
		}
		/*return false;*/
	}

	function comdigex_file_contents( $path ) {
		$comdigex_content = '';
		if ( function_exists( 'realpath' ) ) {
			$filepath = realpath( $path );
		}
		if ( ! $filepath || ! @is_file( $filepath ) ) {
			echo 'error';
			wp_send_json_error( esc_html__( "File doesn't exist or not valid", "webdevia" ) );

			return '';
		}
		if ( ini_get( 'allow_url_fopen' ) ) {
			$comdigex_file_method = 'fopen';
		} else {
			$comdigex_file_method = 'file_get_contents';
		}
		if ( $comdigex_file_method == 'fopen' ) {
			$comdigex_handle = fopen( $filepath, 'rb' );

			if ( $comdigex_handle !== false ) {
				while ( ! feof( $comdigex_handle ) ) {
					$comdigex_content .= fread( $comdigex_handle, 8192 );
				}
				fclose( $comdigex_handle );
			}

			return $comdigex_content;
		} else {
			return file_get_contents( $filepath );
		}
	}
}

global $my_comdigex_Import;
$my_comdigex_Import = new comdigex_Import();


if ( ! function_exists( 'comdigex_dataImport' ) ) {
	function comdigex_dataImport() {
		global $my_comdigex_Import;

		if ( $_POST['import_attachments'] == 1 ) {
			$my_comdigex_Import->attachments = true;
		} else {
			$my_comdigex_Import->attachments = false;
		}

		$folder = "main/";

		$my_comdigex_Import->comdigex_import_content( $folder . $_POST['xml'] );

		die();
	}

	add_action( 'wp_ajax_comdigex_dataImport', 'comdigex_dataImport' );
}


if ( ! function_exists( 'comdigex_menuImport' ) ) {
	function comdigex_menuImport() {
		global $my_comdigex_Import;

		if ( $_POST['delete_menus'] == 1 ) {
			delete_nav_menus();
		}

		if ( $_POST['import_attachments'] == 1 ) {
			$my_comdigex_Import->attachments = true;
		} else {
			$my_comdigex_Import->attachments = false;
		}

		$folder = "files/";
		if ( ! empty( $_POST['example'] ) ) {
			$folder = $_POST['example'] . "/";
		}

		$my_comdigex_Import->comdigex_import_content( $folder . 'menus.xml' );


		$locations            = get_theme_mod( 'nav_menu_locations' );
		$menuname             = 'primary-menu';
		$menu_exists          = wp_get_nav_menu_object( $menuname );
		$menu_id              = $menu_exists->term_id;
		$locations['primary'] = $menu_id;

		set_theme_mod( 'nav_menu_locations', $locations );
		die();
	}

	add_action( 'wp_ajax_comdigex_menuImport', 'comdigex_menuImport' );
}

if ( ! function_exists( 'comdigex_widgetsImport' ) ) {
	function comdigex_widgetsImport() {
		global $my_comdigex_Import;

		$folder = "/files/main/";

		$my_comdigex_Import->import_widgets( $folder . 'widgets.txt' );

		die();
	}

	add_action( 'wp_ajax_comdigex_widgetsImport', 'comdigex_widgetsImport' );
}

if ( ! function_exists( 'comdigex_optionsImport' ) ) {
	function comdigex_optionsImport() {
		global $my_comdigex_Import;

		$folder = "/files/";
		if ( ! empty( $_POST['example'] ) ) {
			$folder = $_POST['example'] . "/";
		}

		$my_comdigex_Import->import_options( $folder . 'options.txt' );

		die();
	}

	add_action( 'wp_ajax_comdigex_optionsImport', 'comdigex_optionsImport' );
}

if ( ! function_exists( 'comdigex_otherImport' ) ) {
	function comdigex_otherImport() {
		global $my_comdigex_Import;

		if ( ! empty( $_POST['example'] ) ) {
			$folder = $_POST['example'] . "/";
		}

		$my_comdigex_Import->import_settings_pages( $folder . 'settingpages.txt' );

		die();
	}

	add_action( 'wp_ajax_comdigex_otherImport', 'comdigex_otherImport' );
}

if ( ! function_exists( 'comdigex_import_options' ) ) {
	function comdigex_import_options() {

		$file = 'a:225:{s:12:"wd_show_logo";s:2:"on";s:12:"wd_show_cart";s:0:"";s:23:"wd_show_top_social_bare";N;s:14:"wd_box_wrapper";s:2:"of";s:15:"wd_menu_in_grid";s:3:"off";s:14:"wd_menu_sticky";s:2:"on";s:13:"wd_show_title";s:2:"of";s:18:"wd_footer_bg_image";s:0:"";s:15:"footer_bg_color";s:7:"#f9f9f9";s:17:"footer_text_color";s:7:"#162466";s:12:"wd_copyright";s:41:"&copy; 2019 Digitalo All rights reserved.";s:12:"wd_poweredby";s:9:"Digitalo ";s:20:"copyright_text_color";s:7:"#162466";s:7:"wd_logo";s:123:"http://themes.webdevia.com/comdigex-creative-digital-agency-wordpress-theme/wp-content/uploads/2019/02/logo-comdigex@2x.png";s:14:"wd_height_logo";s:2:"40";s:11:"wd_404_page";s:0:"";s:12:"wd_home_page";s:0:"";s:10:"wd_favicon";s:0:"";s:16:"wrapper_bg_color";s:0:"";s:13:"primary_color";s:7:"#B15BCD";s:15:"secondary_color";s:7:"#412aab";s:16:"adress_bar_color";s:0:"";s:16:"social_bar_color";s:0:"";s:12:"copyright_bg";s:7:"#f0f4fb";s:9:"header_bg";s:7:"#ffffff";s:12:"container_bg";s:0:"";s:17:"wd_footer_columns";s:12:"four_columns";s:21:"navigation_text_color";s:7:"#162466";s:26:"navigation_bg_color_sticky";s:7:"#ffffff";s:18:"language_area_html";s:0:"";s:25:"comdigex_show_wpml_widget";s:0:"";s:7:"twitter";s:0:"";s:8:"facebook";s:0:"";s:6:"flickr";s:0:"";s:5:"vimeo";s:0:"";s:5:"phone";s:0:"";s:6:"adress";s:0:"";s:20:"wd_body_font_familly";s:7:"Poppins";s:18:"wd_body_font_style";s:6:"normal";s:20:"wd_font-weight-style";s:3:"300";s:27:"wd_main_text_lettre_spacing";s:0:"";s:25:"wd_main-text-font-subsets";s:9:"latin-ext";s:20:"wd_head_font_familly";s:7:"Poppins";s:18:"wd_head_font_style";s:6:"normal";s:28:"wd_heading-font-weight-style";s:3:"600";s:28:"wd_heading-text-font-subsets";s:9:"latin-ext";s:30:"wd_heading_text_lettre_spacing";s:0:"";s:26:"wd_navigation_font_familly";s:7:"Poppins";s:24:"wd_navigation_font_style";s:6:"normal";s:31:"wd_navigation-font-weight-style";s:3:"300";s:31:"wd_navigation-text-font-subsets";s:9:"latin-ext";s:33:"wd_navigation_text_lettre_spacing";s:0:"";s:13:"wd_menu_style";s:8:"creative";s:18:"wd_theme_custom_js";s:0:"";s:19:"wd_page_transitions";s:3:"off";s:11:"height_logo";s:2:"40";s:12:"logo_padding";s:2:"20";s:23:"comdigex_title_bg_image";s:0:"";s:24:"wd_shop_product_per_page";s:2:"12";s:17:"wd_call_to_action";s:154:"&lt;a href=&quot;&quot; class=&quot;wd-btn
			btn-solid btn-color-2 hover-color-1 btn-small btn-round  icon-after&quot;&gt;
			Request Quote		&lt;/a&gt;";s:12:"accent_color";s:7:"#fa4c9a";s:10:"text_color";s:7:"#718494";s:20:"secondary_text_color";s:7:"#a6aab7";s:12:"header_color";s:7:"#2e325b";s:13:"body_bg_color";s:4:"#fff";s:28:"navigation_text_color_sticky";s:7:"#162466";s:30:"navigation_h_text_color_sticky";s:7:"#ff3b33";s:23:"navigation_h_text_color";s:7:"#ff3b33";s:16:"comdigex_map_key";s:39:"AIzaSyCuddKL1Z2WR8og1v2UZpdI7raxkmVJPaI";s:19:"wd_body_font_weight";s:3:"400";s:24:"wd_body_font_weight_list";s:0:"";s:17:"wd_body_font_size";s:4:"15px";s:33:"wd_heading-font-weight-style-list";s:19:"300,400,500,600,700";s:23:"wd_navigation_font_size";s:4:"14px";s:28:"wd_navigation_text_transform";s:9:"uppercase";s:36:"wd_navigation-font-weight-style-list";s:0:"";s:27:"comdigex_mobile_menu_layout";s:7:"default";s:16:"socialmedia_name";s:8:"# # # # ";s:11:"social_icon";s:51:"fa-facebook-f fa-flickr fa-facebook-f fa-instagram ";s:13:"heading_style";s:15:"heading_style_3";s:19:"heading_top_d_space";s:3:"213";s:19:"heading_top_t_space";s:2:"70";s:19:"heading_top_m_space";s:2:"50";s:22:"heading_bottom_d_space";s:3:"100";s:22:"heading_bottom_t_space";s:2:"70";s:22:"heading_bottom_m_space";s:2:"50";s:16:"heading_a_layout";s:9:"s-under-t";s:19:"heading_a_alignment";s:4:"left";s:20:"headings_a_separator";s:4:"none";s:29:"headings_a_separator_position";s:6:"center";s:26:"headings_a_separator_style";s:5:"solid";s:25:"heading_a_separator_color";s:0:"";s:25:"heading_a_separator_width";s:0:"";s:27:"heading_a_title_font_family";s:0:"";s:26:"heading_a_title_font_style";s:0:"";s:27:"heading_a_title_font_weight";s:0:"";s:25:"heading_a_title_font_size";s:0:"";s:26:"heading_a_title_font_color";s:0:"";s:30:"heading_a_title_text_transform";s:0:"";s:27:"heading_a_title_line_height";s:0:"";s:30:"heading_a_title_letter_spacing";s:0:"";s:30:"heading_a_subtitle_font_family";s:7:"Poppins";s:29:"heading_a_subtitle_font_style";s:0:"";s:30:"heading_a_subtitle_font_weight";s:0:"";s:28:"heading_a_subtitle_font_size";s:4:"17px";s:29:"heading_a_subtitle_font_color";s:7:"#162466";s:33:"heading_a_subtitle_text_transform";s:0:"";s:30:"heading_a_subtitle_line_height";s:3:"1.6";s:33:"heading_a_subtitle_letter_spacing";s:0:"";s:16:"heading_b_layout";s:9:"s-under-t";s:19:"heading_b_alignment";s:4:"left";s:20:"headings_b_separator";s:4:"none";s:29:"headings_b_separator_position";s:6:"center";s:26:"headings_b_separator_style";s:5:"solid";s:25:"heading_b_separator_color";s:0:"";s:25:"heading_b_separator_width";s:0:"";s:27:"heading_b_title_font_family";s:0:"";s:26:"heading_b_title_font_style";s:0:"";s:27:"heading_b_title_font_weight";s:0:"";s:25:"heading_b_title_font_size";s:0:"";s:26:"heading_b_title_font_color";s:0:"";s:30:"heading_b_title_text_transform";s:0:"";s:27:"heading_b_title_line_height";s:0:"";s:30:"heading_b_title_letter_spacing";s:0:"";s:30:"heading_b_subtitle_font_family";s:0:"";s:29:"heading_b_subtitle_font_style";s:0:"";s:30:"heading_b_subtitle_font_weight";s:0:"";s:28:"heading_b_subtitle_font_size";s:0:"";s:29:"heading_b_subtitle_font_color";s:0:"";s:33:"heading_b_subtitle_text_transform";s:0:"";s:30:"heading_b_subtitle_line_height";s:0:"";s:33:"heading_b_subtitle_letter_spacing";s:0:"";s:16:"heading_c_layout";s:9:"s-under-t";s:19:"heading_c_alignment";s:4:"left";s:20:"headings_c_separator";s:4:"none";s:29:"headings_c_separator_position";s:6:"center";s:26:"headings_c_separator_style";s:5:"solid";s:25:"heading_c_separator_color";s:0:"";s:25:"heading_c_separator_width";s:0:"";s:27:"heading_c_title_font_family";s:7:"Poppins";s:26:"heading_c_title_font_style";s:0:"";s:27:"heading_c_title_font_weight";s:0:"";s:25:"heading_c_title_font_size";s:4:"22px";s:26:"heading_c_title_font_color";s:7:"#b15bcd";s:30:"heading_c_title_text_transform";s:0:"";s:27:"heading_c_title_line_height";s:3:"1.6";s:30:"heading_c_title_letter_spacing";s:0:"";s:30:"heading_c_subtitle_font_family";s:0:"";s:29:"heading_c_subtitle_font_style";s:0:"";s:30:"heading_c_subtitle_font_weight";s:0:"";s:28:"heading_c_subtitle_font_size";s:0:"";s:29:"heading_c_subtitle_font_color";s:0:"";s:33:"heading_c_subtitle_text_transform";s:0:"";s:30:"heading_c_subtitle_line_height";s:0:"";s:33:"heading_c_subtitle_letter_spacing";s:0:"";s:0:"";N;s:12:"boxed_layout";s:3:"off";s:10:"menu_style";s:9:"corporate";s:18:"menu_mobile_layout";s:2:"on";s:22:"header_contain_to_grid";s:2:"on";s:17:"stick_menu_to_top";s:2:"on";s:22:"page_loading_animation";s:3:"off";s:13:"action_button";s:142:"&lt;a href=&quot;#&quot; class=&quot;wd-btn btn-solid btn-color-2 hover-color-1 btn-small btn-round  icon-after&quot;&gt;Hire Us Now&lt;/a&gt;";s:21:"body_background_image";s:21:"Body Background image";s:12:"bg_home_page";s:6:"Upload";s:13:"show_the_logo";s:2:"on";s:18:"show_website_title";s:3:"off";s:9:"Logo_link";s:118:"http://themes.webdevia.com/comdigital-web-design-agency-wordpress-theme/wp-content/uploads/2019/05/comdigex-logo-2.png";s:11:"logo_height";s:2:"40";s:14:"google_key_map";s:39:"AIzaSyCuddKL1Z2WR8og1v2UZpdI7raxkmVJPaI";s:13:"title_page_bg";s:34:"Default Title Bar background image";s:15:"header_bg_color";s:5:"#fff0";s:14:"nav_text_color";s:4:"#fff";s:19:"sticky_nav_bg_color";s:7:"#162466";s:21:"sticky_nav_text_color";s:7:"#ffffff";s:27:"hover_sticky_nav_text_color";s:7:"#ffffff";s:20:"hover_nav_text_color";s:7:"#162466";s:16:"body_font_family";s:7:"Poppins";s:15:"body_font_style";s:6:"normal";s:16:"body_font_weight";s:3:"400";s:17:"body_font_to_load";s:20:"300 400 500 600 700 ";s:14:"body_font_size";s:0:"";s:19:"body_letter_spacing";s:0:"";s:17:"body_font_subsets";s:9:"latin-ext";s:16:"head_font_family";s:7:"Poppins";s:15:"head_font_style";s:6:"normal";s:16:"head_font_weight";s:3:"600";s:17:"head_font_to_load";s:20:"300 400 500 600 700 ";s:14:"head_font_size";s:0:"";s:19:"head_letter_spacing";s:0:"";s:17:"head_font_subsets";s:9:"latin-ext";s:15:"nav_font_family";s:7:"Poppins";s:14:"nav_font_style";s:6:"normal";s:15:"nav_font_weight";s:3:"500";s:13:"nav_font_size";s:0:"";s:18:"nav_letter_spacing";s:0:"";s:16:"nav_font_subsets";s:9:"latin-ext";s:15:"pagination_type";s:3:"off";s:12:"related_post";s:9:"corporate";s:20:"404_background_image";s:0:"";s:17:"products_per_page";s:0:"";s:14:"product_column";s:0:"";s:9:"footer_bg";s:0:"";s:14:"copyright_text";s:0:"";s:12:"powered_text";s:0:"";s:6:"search";s:14:"Update Options";s:21:"heading_a_top_d_space";s:0:"";s:21:"heading_a_top_t_space";s:0:"";s:21:"heading_a_top_m_space";s:0:"";s:24:"heading_a_bottom_d_space";s:0:"";s:24:"heading_a_bottom_t_space";s:0:"";s:24:"heading_a_bottom_m_space";s:0:"";s:21:"heading_b_top_d_space";s:0:"";s:21:"heading_b_top_t_space";s:0:"";s:21:"heading_b_top_m_space";s:0:"";s:24:"heading_b_bottom_d_space";s:0:"";s:24:"heading_b_bottom_t_space";s:0:"";s:24:"heading_b_bottom_m_space";s:0:"";s:21:"heading_c_top_d_space";s:0:"";s:21:"heading_c_top_t_space";s:0:"";s:21:"heading_c_top_m_space";s:0:"";s:24:"heading_c_bottom_d_space";s:0:"";s:24:"heading_c_bottom_t_space";s:0:"";s:24:"heading_c_bottom_m_space";s:0:"";s:13:"footer_column";s:12:"four_columns";}';


		$options_array = array();

		$options_array = unserialize( $file );
		update_option( "wd_options_array", $options_array );

	}

	add_action( 'wp_ajax_comdigex_import_options', 'comdigex_import_options' );
}

function delete_nav_menus() {
	$menus_list = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
	foreach ( $menus_list as $menu ) {
		wp_delete_nav_menu( $menu->term_id );
	}
}